@@ -20,6 +20,17 @@ class _StreamBuffer(object):
             raise ValueError("no content")
         self.writeStream(chunk, 0, len(chunk))
 
+class AccessCacheOptions(IntEnum):
+    ALL = -1,
+    CALCULATE_FORMULA = 8388617,
+    CELL_DISPLAY = 1048710,
+    CELLS_DATA = 9,
+    CONDITIONAL_FORMATTING = 16777225,
+    GET_FORMULA = 2097152,
+    NONE = 0,
+    POSITION_AND_SIZE = 3,
+    SET_FORMULA = 4194304,
+    VALIDATION = 33554441,
 class AutoFitMergedCellsType(IntEnum):
     EACH_LINE = 3,
     FIRST_LINE = 1,
@@ -746,25 +757,16 @@ class CrossType(IntEnum):
     MINIMUM = 2,
 class DataBarAxisPosition(IntEnum):
     AUTOMATIC = 0,
-    DATA_BAR_AXIS_AUTOMATIC = 0,
-    DATA_BAR_AXIS_MIDPOINT = 1,
-    DATA_BAR_AXIS_NONE = 2,
     MIDPOINT = 1,
     NONE = 2,
 class DataBarBorderType(IntEnum):
-    DATA_BAR_BORDER_NONE = 0,
-    DATA_BAR_BORDER_SOLID = 1,
     NONE = 0,
     SOLID = 1,
 class DataBarFillType(IntEnum):
-    DATA_BAR_FILL_GRADIENT = 1,
-    DATA_BAR_FILL_SOLID = 0,
     GRADIENT = 1,
     SOLID = 0,
 class DataBarNegativeColorType(IntEnum):
     COLOR = 0,
-    DATA_BAR_COLOR = 0,
-    DATA_BAR_SAME_AS_POSITIVE = 1,
     SAME_AS_POSITIVE = 1,
 class DataLabelShapeType(IntEnum):
     BENT_LINE_CALLOUT = 11,
@@ -837,41 +839,40 @@ class DropButtonStyle(IntEnum):
     REDUCE = 3,
 class DynamicFilterType(IntEnum):
     ABOVE_AVERAGE = 0,
-    APRIL = 13,
-    AUGUST = 17,
+    APRIL = 12,
+    AUGUST = 16,
     BELOW_AVERAGE = 1,
     DECEMBER = 9,
-    FEBRUARY = 11,
-    FEBRURAY = 10,
+    FEBRUARY = 10,
     JANUARY = 6,
-    JULY = 16,
-    JUNE = 15,
+    JULY = 15,
+    JUNE = 14,
     LAST_MONTH = 2,
     LAST_QUARTER = 3,
     LAST_WEEK = 4,
     LAST_YEAR = 5,
-    MARCH = 12,
-    MAY = 14,
-    NEXT_MONTH = 19,
-    NEXT_QUARTER = 20,
-    NEXT_WEEK = 21,
-    NEXT_YEAR = 22,
-    NONE = 23,
+    MARCH = 11,
+    MAY = 13,
+    NEXT_MONTH = 18,
+    NEXT_QUARTER = 19,
+    NEXT_WEEK = 20,
+    NEXT_YEAR = 21,
+    NONE = 22,
     NOVEMBER = 8,
     OCTOBER = 7,
-    QUARTER_1 = 24,
-    QUARTER_2 = 25,
-    QUARTER_3 = 26,
-    QUARTER_4 = 27,
-    SEPTEMBER = 18,
-    THIS_MONTH = 28,
-    THIS_QUARTER = 29,
-    THIS_WEEK = 30,
-    THIS_YEAR = 31,
-    TODAY = 32,
-    TOMORROW = 33,
-    YEAR_TO_DATE = 34,
-    YESTERDAY = 35,
+    QUARTER_1 = 23,
+    QUARTER_2 = 24,
+    QUARTER_3 = 25,
+    QUARTER_4 = 26,
+    SEPTEMBER = 17,
+    THIS_MONTH = 27,
+    THIS_QUARTER = 28,
+    THIS_WEEK = 29,
+    THIS_YEAR = 30,
+    TODAY = 31,
+    TOMORROW = 32,
+    YEAR_TO_DATE = 33,
+    YESTERDAY = 34,
 class EmfRenderSetting(IntEnum):
     EMF_ONLY = 0,
     EMF_PLUS_PREFER = 1,
@@ -951,6 +952,7 @@ class FileFormatType(IntEnum):
     MARKDOWN = 57,
     MS_EQUATION = 34,
     NUMBERS = 56,
+    NUMBERS_09 = 56,
     NUMBERS_35 = 62,
     ODF = 49,
     ODG = 50,
@@ -970,6 +972,7 @@ class FileFormatType(IntEnum):
     PPT = 32,
     PPTM = 41,
     PPTX = 26,
+    SPREADSHEET_ML = 15,
     SVG = 28,
     SXC = 60,
     TAB_DELIMITED = 11,
@@ -1274,6 +1277,7 @@ class ImageType(IntEnum):
     SVM = 69,
     TIFF = 67,
     UNKNOWN = 0,
+    WEB_P = 72,
     WMF = 3,
 class InputMethodEditorMode(IntEnum):
     ALPHA = 8,
@@ -1626,18 +1630,6 @@ class OLEDBCommandType(IntEnum):
     SQL_STATEMENT = 2,
     TABLE_NAME = 3,
     WEB_BASED_LIST = 5,
-class OleFileType(IntEnum):
-    DOC = 1,
-    DOCX = 8,
-    MAPI_MESSAGE = 5,
-    MS_EQUATION = 4,
-    PDF = 3,
-    PPT = 2,
-    PPTX = 9,
-    UNKNOWN = 10,
-    XLS = 0,
-    XLSB = 7,
-    XLSX = 6,
 class OoxmlCompliance(IntEnum):
     ECMA_376_2006 = 0,
     ISO_29500_2008_STRICT = 1,
@@ -1826,6 +1818,9 @@ class PdfCompressionCore(IntEnum):
 class PdfCustomPropertiesExport(IntEnum):
     NONE = 0,
     STANDARD = 1,
+class PdfFontEncoding(IntEnum):
+    ANSI_PREFER = 1,
+    IDENTITY = 0,
 class PdfOptimizationType(IntEnum):
     MINIMUM_SIZE = 1,
     STANDARD = 0,
@@ -2314,7 +2309,7 @@ class SaveFormat(IntEnum):
     PDF = 13,
     PPTX = 61,
     SPREADSHEET_ML = 15,
-    SVG = 22,
+    SVG = 28,
     SXC = 60,
     TAB_DELIMITED = 11,
     TIFF = 21,
@@ -2921,7 +2916,6 @@ from com.aspose.cells import CellWatchCollection
 from com.aspose.cells import CharacterBulletValue
 from com.aspose.cells import Color
 from com.aspose.cells import CopyOptions
-from com.aspose.cells import CustomFilter
 from com.aspose.cells import CustomFilterCollection
 from com.aspose.cells import CustomProperty
 from com.aspose.cells import DataSorterKeyCollection
